@@ -87,7 +87,7 @@ def batchSort(input, output, key, bufferSize):
             yield element.obj
 
     from itertools import islice
-    tempdir = args.tempdir + str(uuid.uuid4())
+    tempdir = os.path.join(args.tempdir, str(uuid.uuid4()))
     os.makedirs(tempdir)
     chunks = []
     try:
